@@ -63,7 +63,7 @@ ebic.lmm.reps.bsreg <- function(target, dataset, id, reps = NULL, wei = NULL, ga
         
         i <- 2  
         
-        if ( tool[2] > 0 ) {
+        if ( tool[2] != 0 ) {
           
           while ( tool[i - 1] - tool[i ] > 0  &  NCOL(dat) > 0 )  {   
             
