@@ -9,6 +9,8 @@ perm.zipregs <- function(target, dataset, wei = NULL, check = FALSE, logged = FA
   thres <- threshold * R + 1
   
   if ( ncores <= 1 ) {
+    oop <- options(warn = -1) 
+    on.exit( options(oop) )
     D <- ncol(dataset)
     n <- length(target)
     pvalue <- dof <- loglik <- numeric(D)   
@@ -19,7 +21,6 @@ perm.zipregs <- function(target, dataset, wei = NULL, check = FALSE, logged = FA
     if ( is.null(wei) ) {
       lgy <- sum( lgamma(target1 + 1) )  
       ini <- 2 * Rfast::zip.mle(target)$loglik
-      
       for (i in 1:D) { 
         x <- model.matrix(target ~ ., as.data.frame(dataset[, i]) )
         mod <- glm.fit(x[ - poia, ], target1, family = poisson(log) ) 
@@ -27,7 +28,6 @@ perm.zipregs <- function(target, dataset, wei = NULL, check = FALSE, logged = FA
         g1 <- log( p1 / ( 1 - p1 ) ) 
         pa <- c( g1, mod$coefficients)
         pa[is.na(pa)] <- rnorm( sum(is.na(pa)) )
-        options(warn = -1)
         lik <- nlm( regzip, pa, y1 = target1, x = x, n1 = n1, poia = poia, iterlim = 10000 )
         lik2 <- optim( lik$estimate, regzip, y1 = target1, x = x, n1 = n1, poia = poia, control = list(maxit = 10000) )
         loglik[i] <- lik2$value
@@ -42,6 +42,7 @@ perm.zipregs <- function(target, dataset, wei = NULL, check = FALSE, logged = FA
         }
         pvalue[i] <- (step + 1) / (R + 1) 
       }
+	  
     } else { 
       wei <- wei / sum(wei)
       w0 <- wei[poia]    ;   w1 <- wei[-poia] 
@@ -55,7 +56,6 @@ perm.zipregs <- function(target, dataset, wei = NULL, check = FALSE, logged = FA
         g1 <- log( p1 / ( 1 - p1 ) )
         pa <- c( g1, mod$coefficients)
         pa[is.na(pa)] <- rnorm( sum(is.na(pa)) )
-        options(warn = -1)
         lik <- nlm( regzipwei, pa, y1 = target1, x = x, n1 = n1, w1 = w1, w0 = w0, poia = poia, iterlim = 10000 )
         lik2 <- optim( lik$estimate, regzipwei, y1 = target1, x = x, n1 = n1, w1 = w1, w0 = w0, poia = poia, control = list(maxit = 10000) )  
         loglik[i] <- lik2$value
@@ -78,8 +78,8 @@ perm.zipregs <- function(target, dataset, wei = NULL, check = FALSE, logged = FA
   } else {
     
     if ( is.null(wei) ) {
-      cl <- makePSOCKcluster(ncores)
-      registerDoParallel(cl)
+      cl <- parallel::makePSOCKcluster(ncores)
+      doParallel::registerDoParallel(cl)
       poia <- which( target == 0 ) 
       D <- ncol(dataset)
       n <- length(target)
@@ -88,15 +88,15 @@ perm.zipregs <- function(target, dataset, wei = NULL, check = FALSE, logged = FA
       target1 <- target[ -poia ]   
       lgy <- sum( lgamma(target1 + 1) )  
       ini <- 2 * Rfast::zip.mle(target)$loglik
-      
-      mod <- foreach( i = 1:D, .combine = rbind, .export = "regzip") %dopar% {
+      oop <- options(warn = -1) 
+      on.exit( options(oop) )      
+      mod <- foreach::foreach( i = 1:D, .combine = rbind, .export = "regzip") %dopar% {
         x <- model.matrix(target ~ ., as.data.frame(dataset[, i]) )
         mod <- glm.fit(x[ - poia, ], target1, family = poisson(log) ) 
         p1 <- ( n0 - sum( exp( - mod$fitted.values ) ) ) / n
         g1 <- log( p1 / ( 1 - p1 ) )  
         pa <- c( g1, mod$coefficients)
         pa[is.na(pa)] <- rnorm( sum(is.na(pa)) )
-        options(warn = -1)
         lik <- nlm( regzip, pa, y1 = target1, x = x, n1 = n1, poia = poia, iterlim = 10000 )
         lik2 <- optim( lik$estimate, regzip, y1 = target1, x = x, n1 = n1, poia = poia, control = list(maxit = 10000) )
         loglik <- lik2$value 
@@ -111,11 +111,11 @@ perm.zipregs <- function(target, dataset, wei = NULL, check = FALSE, logged = FA
         pvalue <- (step + 1) / (R + 1) 
         return( c( lik2$par,  pvalue, length(lik2$par) ) )
       }
-      stopCluster(cl)
+      parallel::stopCluster(cl)
       
     } else {  
-      cl <- makePSOCKcluster(ncores)
-      registerDoParallel(cl)
+      cl <- parallel::makePSOCKcluster(ncores)
+      doParallel::registerDoParallel(cl)
       poia <- which( target == 0 ) 
       D <- ncol(dataset)
       n <- length(target)
@@ -126,15 +126,15 @@ perm.zipregs <- function(target, dataset, wei = NULL, check = FALSE, logged = FA
       w0 <- wei[poia]    ;   w1 <- wei[-poia] 
       ini <- 2 * zipmle.wei(target, wei)$loglik
       lgy <- sum( w1 * lgamma(target1 + 1) )  
-      
-      mod <- foreach( i = 1:D, .combine = rbind, .export = "regzipwei" ) %dopar% {
+      oop <- options(warn = -1) 
+      on.exit( options(oop) )     
+      mod <- foreach::foreach( i = 1:D, .combine = rbind, .export = "regzipwei" ) %dopar% {
         x <- model.matrix(target ~ ., as.data.frame(dataset[, i]) )
         mod <- glm.fit( x[ -poia, ], target1, family = poisson(log), weights = w1 ) 
         p1 <- ( n0 - sum( exp( - mod$fitted.values ) ) ) / n
         g1 <- log( p1 / ( 1 - p1 ) )
         pa <- c( g1, mod$coefficients)
         pa[is.na(pa)] <- rnorm( sum(is.na(pa)) )
-        options(warn = -1)
         lik <- nlm( regzipwei, pa, y1 = target1, x = x, n1 = n1, w1 = w1, w0 = w0, iterlim = 10000 )
         lik2 <- optim( lik$estimate, regzipwei, y1 = target1, x = x, n1 = n1, w1 = w1, w0 = w0, control = list(maxit = 10000) )  
         loglik <- lik2$value 
@@ -149,7 +149,7 @@ perm.zipregs <- function(target, dataset, wei = NULL, check = FALSE, logged = FA
         pvalue <- (step + 1) / (R + 1) 
         return( c( lik2$value,  pvalue, length(lik2$par) ) )
       }
-      stopCluster(cl)
+      parallel::stopCluster(cl)
     }
     
     bic <-  2 * mod[, 1] + 2 * lgy + mod[, 3] * log(n) 
@@ -159,9 +159,9 @@ perm.zipregs <- function(target, dataset, wei = NULL, check = FALSE, logged = FA
   
   if (check) {
     if ( sum(id>0) > 0 ) {
-      stat[id] = 0
-      pvalue[id] = 1
-      bic[id] = NA
+      stat[id] <- 0
+      pvalue[id] <- 1
+      bic[id] <- NA
     }
   } 
   cbind(stat, log(pvalue), bic)
